Pizza.py WWW Site - Pizza.py Documentation - Pizza.py Tools

### histo tool

Purpose:

Particle density histogram from a dump.

Description:

The histo tool creates spatial histograms of particle snapshots in a dump file.

The histo constructor takes an object that stores atom snapshots (dump, data) as its argument.

The compute() method creates a histogram in a specific dimension at a desired resolution, averaged across all selected snapshots and atoms in the dump. The returned vectors can be plotted; x is the distance along the chosen dimension, y is the histogram counts.

Usage:

    h = histo(d)                        d = dump/cdump object

    x,y = h.compute('x',N,lo,hi)        compute histogram in dim with N bins

      lo/hi are optional, if not used histo will be over entire box

Related tools:

dump

Prerequisites: none